<?php

namespace App;

/**
 * Add <body> classes
 */
add_filter('body_class', function (array $classes) {
    /** Add page slug if it doesn't exist */
    if (is_single() || is_page() && !is_front_page()) {
        if (!in_array(basename(get_permalink()), $classes)) {
            $classes[] = basename(get_permalink());
        }
    }

    /** Add class if sidebar is active */
    if (display_sidebar()) {
        $classes[] = 'sidebar-primary';
    }

    /** Clean up class names for custom templates */
    $classes = array_map(function ($class) {
        return preg_replace(['/-blade(-php)?$/', '/^page-template-views/'], '', $class);
    }, $classes);

    return array_filter($classes);
});

/**
 * Add "… Continued" to the excerpt
 */
add_filter('excerpt_more', function () {
    return ' <a href="' . get_permalink() . '" class="read-more">' . __('Read More', 'sage') . '</a>';
});

/**
 * Template Hierarchy should search for .blade.php files
 */
collect([
    'index', '404', 'archive', 'events','author', 'category', 'tag', 'taxonomy', 'date', 'home',
    'frontpage', 'page', 'paged', 'search', 'single', 'singular', 'attachment'
])->map(function ($type) {
    add_filter("{$type}_template_hierarchy", __NAMESPACE__.'\\filter_templates');
});

/**
 * Render page using Blade
 */
add_filter('template_include', function ($template) {
    $data = collect(get_body_class())->reduce(function ($data, $class) use ($template) {
        return apply_filters("sage/template/{$class}/data", $data, $template);
    }, []);
    if ($template) {
        echo template($template, $data);
        return get_stylesheet_directory().'/index.php';
    }
    return $template;
}, PHP_INT_MAX);

/**
 * Tell WordPress how to find the compiled path of comments.blade.php
 */
add_filter('comments_template', function ($comments_template) {
    $comments_template = str_replace(
        [get_stylesheet_directory(), get_template_directory()],
        '',
        $comments_template
    );
    return template_path(locate_template(["views/{$comments_template}", $comments_template]) ?: $comments_template);
});


/*
===============================================================================
*  DAC MODIFICATIONS BELOW
===============================================================================
*/

/**
 * Tell WordPress which template to display the sidebar on
 */

add_filter('sage/display_sidebar', function ($display) {
    static $display;
    $get_page_template = basename(get_page_template());
    isset($display) || $display = !in_array(true, [
      // The sidebar will be displayed on all but the following
      is_404(), is_search(), is_home(),
      is_tax(['resource_type','keyword']),
      is_page(['sitemap','contact','contact-us','national','find-your-network']),
      is_post_type_archive(['tribe_events','resources']),
      is_singular(['tribe_events','resources']),
      $get_page_template == 'template-events.blade.php',
    ]);

    return $display;
});


/**
 * Shorten the_excerpt()
 */
function custom_excerpt_length( $length ) {
    if(is_home()){
        return 17; // 17 words
    } else {
        return 25; // 25 words
    }

}
add_filter( 'excerpt_length',  __NAMESPACE__ . '\\custom_excerpt_length', 999 );



/**
* Remove Posts and Comments
*/
add_action('admin_menu', function() {
    remove_menu_page('edit-comments.php');
    remove_menu_page('edit.php');
});

/**
 * Global data
 */
add_action('after_setup_theme', function() {
    // $links array with social media links
    $sm_links = get_field('social_media_links', 'option');
    sage('blade')->share('links', [
        'facebook'   => 'https://facebook.com/' . $sm_links['facebook'],
        'instagram'  => 'https://instagram.com/' . $sm_links['instagram'],
        // 'linkedin'   => 'https://linkedin.com/' . $sm_links['linkedin'],
        'twitter'    => 'https://twitter.com/' . $sm_links['twitter'],
        'youtube'    => 'https://youtube.com/channel/' . $sm_links['youtube'],
        'flickr'     => 'https://flickr.com/' . $sm_links['flickr'],
        //'googleplus' => 'https://plus.google.com/' . $sm_links['google'],
        //'pinterest'  => 'https://pinterest.com/' . $sm_links['pinterest'],
        //'soundcloud' => 'https://soundcloud.com/' . $sm_links['soundcloud'],
        //'tumblr'     => 'https://tumblr.com/' . $sm_links['tumblr'],
        //'vine'       => 'https://vine.co/' . $sm_links['vine'],
    ]);
});

/**
 * Press release search
 */
function template_chooser($template) {
  global $wp_query;
  $post_type = get_query_var('post_type');
  if( $wp_query->is_search && $post_type == 'press-release' )   {
    return locate_template('index.php');  //  redirect to this template
  }
  return $template;
}
add_filter('template_include',  __NAMESPACE__ . '\\template_chooser');

/**
 * Pre get posts stuff
 */
add_filter( 'pre_get_posts', function($query){
    /**
     * Add Updates to regular category archive
     */
    if( !is_admin() && $query->is_main_query() && (is_category() || is_tag()) ) {
        $query->set( 'post_type', array(
            'post', 'nav_menu_item', 'updates'
            ));
        return $query;
    }
});
